import { WebApiContext, WebApiConfiguration } from './core/core';
import { Environment } from './core/core';
import { Oauth2Config } from './core/web-api-configuration';
/**
 * Allows configuration of CoreSDK
 * @export
 * @class CoreSDKConfigurator
 */
export declare class CoreSDKConfigurator {
    /**
     * Set the WebAPI key.
     * @param {string} webApiKey
     * @returns {CoreSDKConfigurator}
     *
     * @memberOf CoreSDKConfigurator
     */
    useWebApiKey(webApiKey: string): CoreSDKConfigurator;
    /**
     * Specifies the private key for CSCoreSDK request signing.
     * @param {string} signingKey
     * @returns {CoreSDKConfigurator}
     *
     * @memberOf CoreSDKConfigurator
     */
    useRequestSigning(signingKey: string): CoreSDKConfigurator;
    /**
     * Set other then the default language cs-CZ.
     * @param {string} language a language to be set
     * @returns {CoreSDKConfigurator} reference for configuration chaining
     *
     * @memberOf CoreSDKConfigurator
     */
    useLanguage(language: string): CoreSDKConfigurator;
    /**
     * Sets the environment which the SDK should use.
     *
     * @param {Environment} environment environment to use
     * @returns {CoreSDKConfigurator} reference for configuration chaining
     *
     * @memberOf CoreSDKConfigurator
     */
    useEnvironment(environment: Environment): CoreSDKConfigurator;
    /**
     * Sets the config for oAuth 2
     *
     * @param {Oauth2Config} oauth2 Oauth2Config to use
     * @returns {CoreSDKConfigurator} reference for configuration chaining
     *
     * @memberOf CoreSDKConfigurator
     */
    useOauth2(oauth2: Oauth2Config): CoreSDKConfigurator;
}
/**
 * Shared WebApiConfiguration
 */
export declare var config: WebApiConfiguration;
/**
 * Internal structure to share information between different SDKs
 */
export declare var sharedContext: WebApiContext;
/**
 * Set the WebAPI key.
 * @param {string} webApiKey
 * @returns {CoreSDKConfigurator}
 */
export declare var useWebApiKey: (webApiKey: string) => CoreSDKConfigurator;
/**
 * Specifies the private key for CSCoreSDK request signing.
 * @param {string} signingKey The private key to sign reguests.
 * @returns {CoreSDKConfigurator} reference for configuration chaining.
 */
export declare var useRequestSigning: (signingKey: string) => CoreSDKConfigurator;
/**
 *  Set other then the default language cs-CZ.
 *  @param {string} language a language to be set.
 *  @returns {CoreSDKConfigurator} reference for configuration chaining.
 */
export declare var useLanguage: (language: string) => CoreSDKConfigurator;
/**
 * Sets the environment which the SDK should use.
 * @param {Environment} environment environment to use
 * @returns {CoreSDKConfigurator} reference for configuration chaining.
 */
export declare var useEnvironment: (environment: Environment) => CoreSDKConfigurator;
/**
 * Sets the config for oAuth 2
 * @param {Oauth2Config} oauth2 Oauth2Config to use
 * @returns {CoreSDKConfigurator} reference for configuration chaining.
 */
export declare var useOauth2: (oauth2: Oauth2Config) => CoreSDKConfigurator;
export * from './core/core';
export * from './web-api/web-api';
export * from './test-utils/judge';
export * from './test-utils/test-utils';
export * from './signing/signing';
