import { WebApiConfiguration } from './web-api-configuration';
import { AccessTokenProvider, AccessToken } from './access-token-provider';
/**
 * @export
 * @class OauthProvider
 * @implements {OathInterface}
 */
export declare class OauthProvider implements OathInterface {
    accessTokenProvider: AccessTokenProvider;
    config: WebApiConfiguration;
    /**
     * Creates an instance of OauthProvider.
     * @param {AccessTokenProvider} accessTokenProvider
     * @param {WebApiConfiguration} config
     *
     * @memberOf OauthProvider
     */
    constructor(accessTokenProvider: AccessTokenProvider, config: WebApiConfiguration);
    /**
     * Returns url for authentication based on provided config
     * @returns {string}
     *
     * @memberOf OauthProvider
     */
    getOauth2Url(): string;
    /**
     * Parses callback uri and extracts information that is used for requesting access token
     *
     * @param {string} url
     * @returns {Promise<AccessToken>}
     *
     * @memberOf OauthProvider
     */
    processRedirect(url: string): Promise<AccessToken>;
}
/**
 * @export
 * @interface OathInterface
 */
export interface OathInterface {
    getOauth2Url(): string;
    processRedirect(url: string): any;
}
