import { Environment } from './environment';
/**
 * Configuration of SDK
 * @export
 * @class WebApiConfiguration
 */
export declare class WebApiConfiguration {
    /**
     * WebApi key to use
     */
    webApiKey: string;
    /**
     * Language to use. Defaults to 'cs-CZ'
     */
    language: string;
    /**
     * Signing key for request signing. It is not set by default.
     */
    signingKey: string;
    /**
     * Environment to use. Default is Sandbox environment
     */
    environment: Environment;
    /**
   * Oath2 configuration. It is not set by default.
   */
    oauth2: Oauth2Config;
    /**
     * Copies the configuration.
     * @returns {WebApiConfiguration}
     *
     * @memberOf WebApiConfiguration
     */
    copy(): WebApiConfiguration;
}
/**
 * Configuration of oAuth2
 * @export
 * @interface Oauth2Config
 */
export interface Oauth2Config {
    /**
     * ID of the client
     */
    clientId: string;
    /**
     * secret of the client
     */
    clientSecret?: string;
    /**
     * URI where client will be redirected upon logging in
     */
    redirectUri?: string;
}
