import { WebApiClient } from '../web-api/web-api-client';
import { Signable } from '../web-api/api-query';
import { RequestSigner } from './request-signer';
import { FilledSigningObject } from './filled-signing-object';
/**
 * @export
 * @class SigningObject
 */
export declare class SigningObject {
    state: string;
    signId: string;
    order: Signable;
    protected requestSigner: RequestSigner;
    /**
     * Creates an instance of SigningObject.
     * @param {any} order
     * @param {WebApiClient} client
     * @param {string} url
     *
     * @memberOf SigningObject
     */
    constructor(order: any, client: WebApiClient, url: string);
    /**
     * Obtains current signing info with full details from the API. This method always fetches fresh `FilledSigningObject` from the API.
     * @returns {Promise<FilledSigningObject>}
     *
     * @memberOf SigningObject
     */
    refreshSigningInfo: () => Promise<FilledSigningObject>;
    /**
     * Obtains current signing info with full details from the API OR it returns itself if this signing object is already a `FilledSigningObject`
     * @returns {Promise<FilledSigningObject>}
     *
     *
     * @memberOf SigningObject
     */
    getInfo: () => Promise<FilledSigningObject>;
    /**
     * Returns true or false based on state property
     * @returns {boolean}
     *
     * @memberOf SigningObject
     */
    isDone: () => boolean;
    /**
     * Returns true or false based on state property
     * @returns {boolean}
     *
     * @memberOf SigningObject
     */
    isOpen: () => boolean;
    /**
     * Returns true or false based on state property
     * @returns {boolean}
     *
     * @memberOf SigningObject
     */
    isCanceled: () => boolean;
}
