import { FilledSigningObject } from './filled-signing-object';
import { RequestSigner } from './request-signer';
import { SigningObject } from './signing-object';
/**
 *
 *
 * @export
 * @class SigningProcess
 */
export declare class SigningProcess {
    signingObject: SigningObject;
    protected requestSigner: RequestSigner;
    /**
     * Creates an instance of SigningProcess.
     * @param {RequestSigner} requestSigner
     * @param {SigningObject} signingObject
     *
     * @memberOf SigningProcess
     */
    constructor(requestSigner: RequestSigner, signingObject: SigningObject);
}
/**
 * @export
 * @class TacSigningProcess
 * @extends {SigningProcess}
 */
export declare class TacSigningProcess extends SigningProcess {
    /**
     * Creates an instance of TacSigningProcess.
     * @param {RequestSigner} requestSigner
     * @param {SigningObject} signingObject
     *
     * @memberOf TacSigningProcess
     */
    constructor(requestSigner: RequestSigner, signingObject: SigningObject);
    /**
     * Finishes signing process with TAC (that usually means signing using OneTimePassword from SMS)
     * You can call this method only if you successfully called `startSigningWithTac` before.
     * @param {string} oneTimePassword
     * @returns {Promise<SigningObject>}
     *
     * @memberOf TacSigningProcess
     */
    finishSigning: (oneTimePassword: string) => Promise<SigningObject>;
}
/**
 * @export
 * @class CaseMobileSigningProcess
 * @extends {SigningProcess}
 */
export declare class CaseMobileSigningProcess extends SigningProcess {
    /**
     * Creates an instance of CaseMobileSigningProcess.
     * @param {RequestSigner} requestSigner
     * @param {SigningObject} signingObject
     *
     * @memberOf CaseMobileSigningProcess
     */
    constructor(requestSigner: RequestSigner, signingObject: SigningObject);
    /**
     * Finishes signing process with CASE_MOBILE (that usually means signing using OneTimePassword from SMS)
     * You can call this method only if you successfully called `startSigningWithCaseMobile` before.
     * @param {string} oneTimePassword
     * @returns {Promise<SigningObject>}
     *
     * @memberOf CaseMobileSigningProcess
     */
    finishSigning: (oneTimePassword: string) => Promise<SigningObject>;
}
/**
 * @export
 * @class NoAuthSigningProcess
 * @extends {SigningProcess}
 */
export declare class NoAuthSigningProcess extends SigningProcess {
    /**
     * Creates an instance of NoAuthSigningProcess.
     * @param {RequestSigner} requestSigner
     * @param {SigningObject} signingObject
     *
     * @memberOf NoAuthSigningProcess
     */
    constructor(requestSigner: RequestSigner, signingObject: SigningObject);
    /**
     * Finishes signing process using NO_AUTHORIZATION method
     * You can call this method only if you successfully called `startSigningWithNoAuthorization` before.
     * @returns {Promise<FilledSigningObject>}
     *
     * @memberOf NoAuthSigningProcess
     */
    finishSigning: () => Promise<FilledSigningObject>;
}
