import { Resource } from './resource';
import { ListResponse, PaginatedListResponse } from './lists';
/**
 * @export
 * @class ResourceUtils
 */
export declare class ResourceUtils {
    /**
     * @static
     * @template TResponse
     * @param {Resource} resource
     * @param {any} params
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallGet<TResponse>(resource: Resource, params: any): Promise<TResponse>;
    /**
     * @static
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {any} params
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallGetWithSuffix<TResponse>(resource: Resource, pathSuffix: string, params: any): Promise<TResponse>;
    /**
     * @static
     * @template TRequest
     * @template TResponse
     * @param {Resource} resource
     * @param {TRequest=} payload
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallCreate<TRequest, TResponse>(resource: Resource, payload?: TRequest): Promise<TResponse>;
    /**
     * @static
     * @template TRequest
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {TRequest=} payload
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallCreateWithSuffix<TRequest, TResponse>(resource: Resource, pathSuffix: string, payload?: TRequest): Promise<TResponse>;
    /**
     * @static
     * @template TRequest
     * @template TResponse
     * @param {Resource} resource
     * @param {TRequest=} payload
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallUpdate<TRequest, TResponse>(resource: Resource, payload?: TRequest): Promise<TResponse>;
    /**
     * @static
     * @template TRequest
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {TRequest=} payload
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallUpdateWithSuffix<TRequest, TResponse>(resource: Resource, pathSuffix: string, payload?: TRequest): Promise<TResponse>;
    /**
     * @static
     * @template TResponse
     * @param {Resource} resource
     * @param {any} params
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallDelete<TResponse>(resource: Resource, params: any): Promise<TResponse>;
    /**
     * @static
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {any} params
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallDeleteWithSuffix<TResponse>(resource: Resource, pathSuffix: string, params: any): Promise<TResponse>;
    /**
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {string} method
     * @param {any=} params
     * @param {Uint8Array} data
     * @param {any=} headers
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    UploadDataWithSuffix<TResponse>(resource: Resource, pathSuffix: string, method: string, params: any, data: Uint8Array, headers?: any): Promise<TResponse>;
    /**
     * @static
     * @template TData
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {string} method
     * @param {any=} params
     * @param {TData=} data
     * @param {any=} headers
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallDownload<TData, TResponse>(resource: Resource, pathSuffix: string, method: string, params?: any, data?: TData, headers?: any): Promise<TResponse>;
    /**
     * @static
     * @template TData
     * @template TResponse
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {string} method
     * @param {any=} params
     * @param {TData=} data
     * @param {any=} headers
     * @param {string=} responseType
     * @returns {Promise<TResponse>}
     *
     * @memberOf ResourceUtils
     */
    static CallApiWithSuffix<TData, TResponse>(resource: Resource, pathSuffix: string, method: string, params?: any, data?: TData, headers?: any, responseType?: string): Promise<TResponse>;
    /**
     * @static
     * @template TItem
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {string=} itemsKey
     * @param {any=} params
     * @param {function=} responseTransform
     * @returns {Promise<PaginatedListResponse<TItem>>}
     *
     * @memberOf ResourceUtils
     */
    static CallPaginatedListWithSuffix<TItem>(resource: Resource, pathSuffix: string, itemsKey?: string, params?: any, responseTransform?: (response: PaginatedListResponse<TItem>) => PaginatedListResponse<TItem>): Promise<PaginatedListResponse<TItem>>;
    /**
     * @static
     * @template TItem
     * @param {Resource} resource
     * @param {string} pathSuffix
     * @param {string=} itemsKey
     * @param {any=} params
     * @returns {Promise<ListResponse<TItem>>}
     *
     * @memberOf ResourceUtils
     */
    static CallListWithSuffix<TItem>(resource: Resource, pathSuffix: string, itemsKey?: string, params?: any): Promise<ListResponse<TItem>>;
}
