import { WebApiClient, PathSegment } from './web-api-client';
/**
 * @export
 * @abstract
 * @class Resource
 * @implements {PathSegment}
 */
export declare abstract class Resource implements PathSegment {
    protected _client: WebApiClient;
    protected _path: string;
    /**
     * Creates an instance of Resource.
     * @param {string} basePath
     * @param {WebApiClient} client
     *
     * @memberOf Resource
     */
    constructor(basePath: string, client: WebApiClient);
    /**
     * Returns the associated WebApiClient
     * @returns {WebApiClient}
     *
     * @memberOf Resource
     */
    getClient(): WebApiClient;
    /**
     * Returns current URL path
     * @returns {string}
     *
     * @memberOf Resource
     */
    getPath(): string;
    /**
     * @protected
     * @param {string} appendix
     * @returns {string}
     *
     * @memberOf Resource
     */
    protected pathAppendedWith(appendix: string): string;
    /**
     * @protected
     * @param {any=} params
     * @returns {Promise<any>}
     *
     * @memberOf Resource
     */
    protected _get(params?: any): Promise<any>;
    /**
     * @protected
     * @param {string} pathSuffix
     * @param {any=} params
     * @returns {Promise<any>}
     *
     * @memberOf Resource
     */
    protected _getWithSuffix(pathSuffix: string, params?: any): Promise<any>;
}
